@@ -1,7 +1,7 @@
 import os
 import glob
 import argparse
-from sys import argv
+from sys import argv, stdout
 import importlib.resources
 from ez_docs import cmd
 
@@ -23,8 +23,15 @@ def clean_dir_md():
     # Delete the files.
     for file_name in target_file_names:
         os.remove(file_name)
+    os.remove('mdpdf.log')
 
-class call_command(argparse.Action):
+def progress_bar(index: int, amount: int, char: str, final_length: int = 25):
+    stdout.write("\033[F\033[K\033[F\033[K\033[F\033[K")
+    print(f"\033[93m({index}/{amount})\033[0m {index * 100/amount: 1.2f}% [\033[96m", end='')
+    charline = "".join([char for _ in range(round(final_length*index/amount))])
+    print(charline + "\033[0m]")
+
+class CallCommand(argparse.Action):
     def __call__(self, parser, namespace, values, option_string):
         #Catch the last argument given in the sys.arg
         command = argv[-1].lstrip('-')
@@ -32,8 +39,8 @@ class call_command(argparse.Action):
         #Open the txt response
         path = importlib.resources.files(cmd)
         
-        with open(file=f'{path}\{command}.txt', encoding='utf-8') as f:
+        with open(file=f'{path}/{command}.txt', encoding='utf-8') as f:
            data = f.read()
            print(data)
         #Close the parser
-        parser.exit()
\ No newline at end of file
+        parser.exit()
